@@ -1,13 +1,13 @@
-# Copyrights 2014-2015 by [Mark Overmeer].
+# Copyrights 2014-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::WSDL11;
 use vars '$VERSION';
-$VERSION = '3.04';
+$VERSION = '3.05';
 
 use base 'XML::Compile::Cache';
 
@@ -193,21 +193,26 @@ sub addWSDL($%)
         my @portTypes = map $_->{wsdl_portType}||(), @$toplevels;
         @portTypes==1
             or error __x"no service definition so needs 1 portType, found {nr}"
-                 , nr => scalar @portTypes;
+              , nr => scalar @portTypes;
 
         my @bindings = map $_->{wsdl_binding}||(), @$toplevels;
         @bindings==1
             or error __x"no service definition so needs 1 binding, found {nr}"
-                 , nr => scalar @bindings;
+              , nr => scalar @bindings;
 
         my $binding  = pack_type $tns, $bindings[0]->{name};
         my $portname = $portTypes[0]->{name};
         my $servname = $portname;
         $servname =~ s/Service$|(?:Service)?Port(?:Type)?$/Service/i
-             or $servname .= 'Service';
+            or $servname .= 'Service';
+
+        my $addr
+          = $bindings[0]->{soap_binding}   ? 'soap_address'
+          : $bindings[0]->{soap12_binding} ? 'soap12_address'
+          : error __x"unrecognized binding type for wsdl without service block";
 
         my %port = (name => $portname, binding => $binding
-           , soap_address => {location => 'http://localhost'} );
+           , $addr => {location => 'http://localhost'} );
 
         $index->{service}{pack_type $tns, $servname}
             = { name => $servname, wsdl_port => [ \%port ] };
@@ -235,11 +240,11 @@ sub operation(@)
     ## Service structure
     #
 
-    my $service   = $self->findDef(service => delete $args{service});
+    my $service = $self->findDef(service => delete $args{service});
 
     my $port;
-    my @ports     = @{$service->{wsdl_port} || []};
-    if(my $not = first {blessed $_} @ports)
+    my @ports   = @{$service->{wsdl_port} || []};
+    if(my $not  = first {blessed $_} @ports)
     {   error __x"not all name-spaces loaded, {ns} not parsed in port"
           , ns => $not->namespaceURI;
     }
